@@ -2,13 +2,13 @@ from pyield.anbima.ettj import intraday_ettj, last_ettj
 from pyield.anbima.ima import last_ima
 from pyield.anbima.imaq import imaq
 from pyield.anbima.ipca import ipca_projection
-from pyield.anbima.tpf import fetch_tpf_data, tpf_data, tpf_fixed_rate_maturities
+from pyield.anbima.tpf import _fetch_tpf_data, tpf_data, tpf_fixed_rate_maturities
 
 __all__ = [
     "last_ima",
     "imaq",
     "ipca_projection",
-    "fetch_tpf_data",
+    "_fetch_tpf_data",
     "tpf_data",
     "tpf_fixed_rate_maturities",
     "last_ettj",
