@@ -15,7 +15,7 @@ import requests
 
 from pyield import bday
 from pyield import date_converter as dc
-from pyield.bc import ptax
+from pyield.bc import ptax_api as pt
 from pyield.date_converter import DateScalar
 from pyield.retry import default_retry
 from pyield.tn.ntnb import duration as duration_b
@@ -153,10 +153,7 @@ def _process_df(df: pd.DataFrame) -> pd.DataFrame:
     df["AvgPrice"] = df["AvgPrice"].where(keep_avg_price, adjusted_avg_price)
 
     # Usar a data de liquidação para calcular o número de dias úteis até o vencimento
-    df["BDToMat"] = bday.count(
-        start=df["Settlement"],
-        end=df["Maturity"],
-    ).astype("int64[pyarrow]")
+    df["BDToMat"] = bday.count(start=df["Settlement"], end=df["Maturity"])
 
     return df
 
@@ -220,7 +217,7 @@ def _add_dv01(df: pd.DataFrame) -> pd.DataFrame:
 
 def _get_ptax_df(start_date: dt.date, end_date: dt.date) -> pd.DataFrame:
     # A série de leilões começa em 2007
-    df = ptax.ptax_series(start=start_date, end=end_date)
+    df = pt.ptax_series(start=start_date, end=end_date)
     return df[["Date", "MidRate"]].rename(columns={"MidRate": "PTAX"})
 
 
